from torchsynth.__info__ import __author_email__  # noqa: F401
from torchsynth.__info__ import (
    __author__,
    __copyright__,
    __docs__,
    __homepage__,
    __license__,
    __version__,
)
